@@ -1,9 +1,9 @@
 #!@PERL@ -w
 ##
 ##  OSSP snmpdx - SNMP Daemon Extension
-##  Copyright (c) 2003 The OSSP Project <http://www.ossp.org/>
-##  Copyright (c) 2003 Ralf S. Engelschall <rse@engelschall.com>
-##  Copyright (c) 2003 Cable & Wireless <http://www.cw.com/>
+##  Copyright (c) 2003-2005 The OSSP Project <http://www.ossp.org/>
+##  Copyright (c) 2003-2005 Ralf S. Engelschall <rse@engelschall.com>
+##  Copyright (c) 2003-2005 Cable & Wireless <http://www.cw.com/>
 ##
 ##  This file is part of OSSP snmpdx, a SNMP daemon extension which
 ##  can be found at http://www.ossp.org/pkg/tool/snmpdx/.
@@ -520,7 +520,7 @@ my %options = (
 Getopt::Long::Configure("bundling");
 my $result = GetOptions(%options) || die "option parsing failed";
 if ($opt->{'help'}) {
-    print "Usage: $prg->{'name'} [options] [SPECFILE ...]\n" .
+    print "Usage: $prg->{'name'} [options] [MIB OID ...]\n" .
           "Available options:\n" .
           " -c,--config=PATH    read command line options from configuration fil\n" .
           " -V,--version        print program version\n" .
